@@ -86,17 +86,38 @@ class BaseMongoDB(object):
         """
         return self.task.update_one(key, {"$pull": obj}, upsert=True).raw_result
 
-    def pull_many(self, key: dict, obj: dict):
-        """从array删除满足条件的所有数据"""
-        return self.task.update_many(key, {"$pull": obj}, upsert=True).raw_result
+    def pull_many(self, key: dict, where, obj: dict, result=True):
+        """从array删除满足条件的所有数据,并返回内容"""
 
-    def pop_one(self, key: dict, where: str):
+        def issubset(a: dict, b: dict):
+            return set(a.items()).issubset(b.items())
+
+        if result:
+            res = []
+            raw = self.task.find_and_modify(key, {"$pull": {where: obj}}, upsert=True)
+            for item in obj:
+                if '$regex' in obj[item]:
+                    # 处理正则搜索情况
+                    key = item
+                    word = obj[item]['$regex'][1:]
+                    for i in raw[where]:
+                        if str(i[key]).startswith(word):
+                            res.append(i)
+                    return res
+            for item in raw[where]:
+                if issubset(obj, item):
+                    res.append(item)
+            return res
+        else:
+            return self.task.find(key, {"$pull": {where: obj}}, upsert=True)
+
+    def pop_one(self, key: dict, where: str) -> dict:
         """
         从array弹出最早的一条数据
         注意目前where只支持一级目录，不支持比较复杂位置的array（后期再优化吧
         """
         res = self.task.find_one_and_update(key, {"$pop": {where: -1}}, upsert=True)
-        return res[where][0] if res[where] else []
+        return res[where][0] if res[where] else {}
 
     def increment_one(self, key: dict, obj_key: str, step: int):
         """
@@ -174,3 +195,19 @@ def _m_to_point(t: dict, m='|'):
             nk = str(key).replace(m, '.')
             t[nk] = t.pop(key)
     return t
+
+
+if __name__ == "__main__":
+    db = BaseMongoDB(name='vul', host='localhost', port=27017, db='asmp',
+                     user='root', password='ya123456', source='admin')
+    # db.push_one({'id': 0}, 'standby', {'task_id': '1_123', 'number': 'heyhey123'})
+    # db.push_one({'id': 0}, 'standby', {'task_id': '1_123', 'number': 'heyhey12345'})
+    # db.push_one({'id': 0}, 'standby', {'task_id': '1_2345', 'number': 'heyhey234'})
+
+    res = db.find({'task_id': {"$regex": '^{}'.format('4623271')}, 'status': 0})
+    if len(res) == 0 :
+        print("?")
+    else:
+        print('yes')
+    for item in res:
+        pass
