@@ -32,7 +32,7 @@ class ExecShellRemote:
         self.username = username
         self.password = password
 
-    def create_remote_connection(self) -> bool:
+    def create_remote_connection(self, info=False) -> bool:
         try:
             # 实例化SSHClient
             self.client = paramiko.SSHClient()
@@ -41,7 +41,7 @@ class ExecShellRemote:
             self.client.connect(hostname=self.hostname, port=self.port, username=self.username, password=self.password)
             return True
         except Exception as e:
-            logger.error(e, exc_info=True)
+            logger.error(e, exc_info=info)
             return False
 
     def remote_exec(self, cmd):
